@@ -25,6 +25,7 @@ settings.configure(default_settings=settings_default,
                    },
                    SEND_BACKLINKS=False,
                    JABBER_DEFAULT_HOST=None,
+                   PERMISSIONS_CACHE=False
                    )
 
 django.setup()
@@ -34,6 +35,7 @@ test_runner = DiscoverRunner(verbosity=1)
 
 failures = test_runner.run_tests([
     'djangoldp_circle.tests.tests_permissions',
+    'djangoldp_circle.tests.tests_save'
 ])
 if failures:
     sys.exit(failures)
